@@ -1,14 +1,16 @@
 from crispy_forms import helper as crispy_forms_helper
 from crispy_forms.utils import TEMPLATE_PACK
 
+from crispy_forms_gds.layout import Size
+
 
 class FormHelper(crispy_forms_helper.FormHelper):
     """
-    .. _FormHelper: https://django-crispy-forms.readthedocs.io/en/latest/form_helper.html
+    .. _FormHelper: https://django-crispy-forms.readthedocs.io/en/latest/form_helper.html  # noqa
 
     This class controls the form rendering behavior of the form passed to
     the ``{% crispy %}`` tag. It intended to be use exclusively with the 'gds'
-    template pack and extends the django-crispy-forms `FormHelper`_ class by
+    template pack and extends the django-crispy-forms FormHelper class by
     adding the following attributes to control how the form is rendered.
 
     Attributes:
@@ -74,8 +76,8 @@ class FormHelper(crispy_forms_helper.FormHelper):
         form.use_required_attribute = False
 
         if self.label_size:
-            context["label_size"] = self.label_size
+            context["label_size"] = Size.for_label(self.label_size)
         if self.legend_size:
-            context["legend_size"] = self.legend_size
+            context["legend_size"] = Size.for_legend(self.legend_size)
 
         return super().render_layout(form, context, template_pack=template_pack)
